import { AnimateSharedLayout } from 'framer-motion';
import React, { useState } from 'react';
import styled from 'styled-components';

import {
  Notifications,
  NotificationsButton,
} from '@components/Notifications';
import { ConstitutionIcon } from '@components/page/Sidebar/LinksIcons/ConstitutionIcon';
import { CouncilIcon } from '@components/page/Sidebar/LinksIcons/CouncilIcon';
import { FinancialsIcon } from '@components/page/Sidebar/LinksIcons/FinancialsIcon';
import { ForumIcon } from '@components/page/Sidebar/LinksIcons/ForumIcon';
import { MembersIcon } from '@components/page/Sidebar/LinksIcons/MembersIcon';
import { MyProfileIcon } from '@components/page/Sidebar/LinksIcons/MyProfileIcon';
import { OverviewIcon } from '@components/page/Sidebar/LinksIcons/OverviewIcon';
import { ProposalsIcon } from '@components/page/Sidebar/LinksIcons/ProposalsIcon';
import { SettingsIcon } from '@components/page/Sidebar/LinksIcons/SettingsIcon';
import { ValidatorsIcon } from '@components/page/Sidebar/LinksIcons/ValidatorsIcon';
import { WorkingGroupsIcon } from '@components/page/Sidebar/LinksIcons/WorkingGroupsIcon';
import { LogoLink } from '@components/page/Sidebar/LogoLink';
import {
  Navigation,
  NavigationInnerWrapper,
} from '@components/page/Sidebar/Navigation';
import { NavigationHeader } from '@components/page/Sidebar/NavigationHeader';
import { NavigationLink } from '@components/page/Sidebar/NavigationLink';
import { RemoveScrollbar } from '@common/constants';
import { CouncilRoutes } from '@/council/constants';
import { ForumRoutes } from '@/forum/constant';
import { ProfileComponent } from '@/memberships/components/ProfileComponent';
import { ProposalsRoutes } from '@/proposals/constants/routes';

import { routes, useStyles } from "./config";

const Bar = () => {
  const [show, setShow] = useState(true);

  return (
    <div>
      <MobileButton show={show} onClick={() => setShow(!show)}>{show ? 'X' : '|||'}</MobileButton>
      <JSSNavigation show={show}>
        <NavigationInnerWrapper>
          <JSSNavigationHeader>
            <LogoLink />stats
          </JSSNavigationHeader>
          <AnimateSharedLayout>
            <NavigationLinks>
              {Object.keys(routes).map(route => (
                <NavigationLinksItem>
                  <NavigationLink to={route}>
                    <OverviewIcon />
                    {routes[route]}
                  </NavigationLink>
                </NavigationLinksItem>
              ))}
            </NavigationLinks>
          </AnimateSharedLayout>
        </NavigationInnerWrapper>
      </JSSNavigation>
    </div>
  );
};

export default Bar;

const JSSNavigation = styled(Navigation)`
  ${({ show }: any) => show ? null : 'display: none;'}
  @media screen and (max-width: 800px) {
    max-width: 100%;
  }
`;

const JSSNavigationHeader = styled(NavigationHeader)`
  justify-content: normal
`;

const MobileButton = styled.button`
  display: none;
  @media screen and (max-width: 800px) {
    position: absolute;
    top: 14px;
    right: 14px;
    z-index: 10000;
    display: block;
    color: ${({ show }: any) => (show ? '#fff' : '#000')};
  }
`;

const NavigationLinks = styled.ul`
  display: flex;
  flex-direction: column;
  width: 100%;
  grid-area: barlinks;
  list-style: none;
  max-height: 100%;
  overflow: hidden;
  overflow-y: scroll;
  mask-image: linear-gradient(0deg, transparent 0px, black 8px, black calc(100% - 8px), transparent 100%);
  ${RemoveScrollbar};
`

const NavigationLinksItem = styled.li`
  display: flex;
  height: fit-content;
  width: 100%;
`
