import { useState, useEffect } from 'react';
import styled from 'styled-components';
// import { Table } from 'react-bootstrap';
import axios from 'axios';

import { PageLayout, PageHeaderWrapper } from '@app/components/PageLayout';
import { PageTitle } from '@common/components/page/PageTitle';
import { List } from '@common/components/List';
import { ListHeader, ListHeaders } from '@common/components/List/ListHeader';
import { TableListItem } from '@common/components/List';
import {
  HeaderText,
  SortIconDown,
  SortIconUp,
} from '@components/SortedListHeaders';
import { TextBig, TokenValue } from '@common/components/typography';
import { BorderRad, Colors, Transitions } from '@common/constants';

import { Column } from 'react-table';

import Loading from '../../Loading';
import Table from '../../table/table';
import tableComponents from '../../table/tableComponents';

interface IBounty {
  id: any;
  title: string;
  description: string;
  format: string;
  openedDate: any;
  status: string;
  reward: string | number;
  manager: string[];
  links: string[];
}

const columns: Column[] = [
  {
    Header: 'ID',
    accessor: 'id',
  },
  {
    Header: 'Title',
    accessor: 'title',
  },
  {
    Header: 'Links',
    accessor: 'links',
    // TODO: format()
  },
  {
    Header: 'Reward',
    accessor: 'reward',
  },
  {
    Header: 'Manager, Co',
    accessor: 'manager',
  },
  {
    Header: 'Status/Grading',
    accessor: 'status',
  },
];

function Bounties() {
  const [bounties, setBounties] = useState<IBounty[] | null>(null);

  const fetchBounties = async () => {
    const response = await axios.get<{ activeBounties: IBounty[] }>(
      `https://raw.githubusercontent.com/Joystream/community-repo/master/bounties/bounties-status.json`
    );

    setBounties(response.data?.activeBounties);
  };

  useEffect(() => {
    fetchBounties();
  }, []);

  if (!bounties) return <Loading target={`bounties`} />;

  return (
    <div className="Bounties m-2 p-1 bg-light">
      <Table
        id="testTable"
        columns={columns}
        data={bounties}
        tableComponents={tableComponents}
        SortIconDown={SortIconDown}
        SortIconUp={SortIconUp}
        getCellProps={(cell: any) => ({
          'aria-label': cell.column.Header,
        })}
      />
    </div>
  );
}
export default Bounties;
