import React, { useEffect, useState } from 'react';
import { Link } from "react-router-dom";
import styled from 'styled-components';
import axios from "axios";
// import {
//   Accordion,
//   AccordionSummary,
//   createStyles,
//   Grid,
//   makeStyles,
//   Theme,
//   Typography,
// } from "@material-ui/core";
// import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import {
  Checkbox,
  InlineToggleWrap,
  InputComponent,
  InputText,
  InputTextarea,
  Label,
  LabelLink,
  ToggleCheckbox,
} from '@components/forms';
import { BlockDurationStatistics, MultiValueStat, Statistics } from '@common/components/statistics'
import { Tokenomics } from "../../types";
import { Loading } from "..";

import tableComponents from '../table/tableComponents';
import Table from '../table/table';
import Select from '../Select';
import JSStatistics from '../components/Block/Statistics';
import StatisticsBlock, {
  JSStatsBlock,
  StatsContent,
} from '../components/Block/StatsBlock';

import { LeaderboardMember, CouncilMember, Kpi } from './types';

const baseUrl = `https://joystreamstats.live/static`;

const gradingTableColumns: Column[] = [
  {
    Header: '#',
    accessor: 'index',
  },
  {
    Header: 'Member',
    accessor: 'handle',
    format: (handle, m) => (
      <Link className="text-light" to={`/members/${m.handle}`}>
        {handle}
      </Link>
    ),
  },
  {
    Header: 'Reward USD',
    accessor: 'rewardUsd',
  },
  {
    Header: 'Reward M tJOY',
    accessor: 'rewardJoy',
  },
];

// const useStyles = makeStyles((theme: Theme) =>
//   createStyles({
//     root: {
//       textAlign: "center",
//       backgroundColor: "#000",
//       color: "#fff",
//     },
//     acc: {
//       color: "#fff",
//       backgroundColor: "#4138ff",
//     },
//     heading: {
//       fontSize: theme.typography.pxToRem(25),
//       fontWeight: theme.typography.fontWeightRegular,
//     },
//   })
// );

const Grading = (props: {
  leaderboard: LeaderboardMember[];
  tokenomics: Tokenomics;
}) => {
  const { tokenomics } = props;
  const [kpi, setGrading] = useState(null);
  const [currentKpi, setCurrentKpi] = useState(null);
  const price = tokenomics ? tokenomics.price : 30 / 1000000;

  useEffect(() => {
    axios
      .get(`${baseUrl}/kpi-grading.json`)
      .then(({ data }) => setGrading(data))
      .catch((e) => console.error(`Failed to fetch KPI grading data.`, e));
  }, []);

  useEffect(() => {
    const newKpi = kpi?.length > 0 ? kpi[0]?.kpi : null;
    // console.log('newKpi', newKpi);
    
    setCurrentKpi(newKpi);
  }, [kpi])

  if (!kpi?.length) return <Loading target="data" />;

  const gradingData = kpi?.find(k => k.kpi === currentKpi);

  const gradingDataCouncilMembers = gradingData?.councilMembers.map(cm => ({
    ...cm,
    rewardJoy: (cm.rewardUsd / price / 1000000).toFixed(1)
  }));

  const options = kpi.map(k => ({
    key: k.kpi,
    value: k.kpi,
    label: `Round ${k.kpi}`,
  }));

  // console.log('currentKpi', currentKpi);
  // console.log('gradingData', gradingData);

  if (true) {
    return (
      <>
        {/* <h3>grading</h3> */}
        <Form>
          <InputComponent required inputSize="l">
            <Select
              onChange={(item) => setCurrentKpi(item.value)}
              options={options}
            />
          </InputComponent>
        </Form>
        {gradingData && (
          <>
            <JSStatistics>
              <StatisticsBlock
                title="Councilor Reward"
                items={[
                  { label: 'Max', value: gradingData?.totalPossibleRewardsUsd },
                  {
                    label: 'TJoy',
                    value: gradingData?.totalRewardTjoy,
                    type: 'blocks',
                  },
                  {
                    label: 'USD',
                    value: gradingData?.totalRewardUsd,
                  },
                ]}
              />
              {/* <MultiValueStat
                size="s"
                title="Councilor Reward"
                values={[
                  { label: 'Max', value: gradingData?.totalPossibleRewardsUsd },
                  { label: 'TJoy', value: gradingData?.totalRewardTjoy, type: 'blocks' },
                ]}
              /> */}
            </JSStatistics>
            {/* <b>max: {gradingData?.totalPossibleRewardsUsd}</b> */}
            <Table
              id="grading-table"
              columns={gradingTableColumns}
              data={gradingDataCouncilMembers}
              tableComponents={tableComponents}
            />
          </>
        )}
      </>
    );
  }
};

const Form = styled.div`
  margin-bottom: 24px;
`;

export default React.memo(Grading);
