import React, { ReactNode } from 'react';
import styled from 'styled-components';
import Markdown from 'react-markdown';
import gfm from 'remark-gfm';

import { CloseButton } from '@components/buttons';
import { Loading } from '@components/Loading';
import { ModalFooter } from '@components/Modal';
import {
  EmptyBody,
  SidePane,
  SidePaneBody,
  SidePaneGlass,
  SidePaneHeader,
  SidePanelTop,
  SidePaneTitle,
} from '@components/SidePane';
import { TabProps, Tabs } from '@components/Tabs';
import { useEscape } from '@common/hooks/useEscape';
import { useModal } from '@common/hooks/useModal';
import { Member } from '@memberships/types';
import { Label, TextBig, TextInlineBig } from '@components/typography';
// import { EmptyBody } from '@/proposals/modals/VoteRationale/VoteRationale';

import {
  List,
  ListColumn,
  ListText,
  ListRow,
  ListLabel,
} from '../../components/List';

import { MarkdownText } from '../utils';

// import { MemberInfoWrap } from '..'
// import { MemberInfo } from '../MemberInfo'

import { useShowKpiModal, KpiModalCall } from './useShowKpiModal';

export const KpiModal = React.memo((props) => {
  // const {
  //   kpi,
  //   isLoading,
  //   tabs,
  //   children,
  //   contextButtons,
  //   title,
  //   closeModal,
  //   footer,
  // } = props;
  const { modalData: kpi } = useModal<KpiModalCall>();
  const {
    scope,
    rewardDistribution,
    id,
    title,
    reward,
    fiatPool,
    distribution,
    process,
    active,
  } = kpi;
  // console.log('KpiModal', props);
  console.log('KpiModal kpi', kpi);
  // console.log('KpiModal children', children);
  // console.log('isLoading', isLoading);

  const { hideModal } = useModal();

  const onBackgroundClick = (
    e: React.MouseEvent<HTMLDivElement, MouseEvent>
  ) => {
    if (e.target === e.currentTarget) {
      hideModal();
    }
  };

  useEscape(() => hideModal());

  // if (isLoading || !kpi) {
  //   return (
  //     <SidePaneGlass onClick={onBackgroundClick}>
  //       <SidePane>
  //         <SidePaneBody>
  //           <Loading />
  //         </SidePaneBody>
  //       </SidePane>
  //     </SidePaneGlass>
  //   );
  // }

  // https://pioneer-2.netlify.app/#/members
  return (
    <SidePaneGlass onClick={onBackgroundClick}>
      <SidePaneKpi>
        {!kpi && (
          <SidePaneBody>
            <Loading />
          </SidePaneBody>
        )}
        {kpi && (
          <>
            <SidePaneHeader>
              <SidePanelTop>
                <SidePaneTitle>{kpi.title}</SidePaneTitle>
                {/* {contextButtons} */}
                <CloseButton onClick={hideModal} />
                <>
                  <List>
                    <ListRow>
                      <ListLabel text="ID" />
                      <ListText>{id}</ListText>
                    </ListRow>
                    <ListRow>
                      <ListLabel text="Reward" />
                      <ListText>{reward}</ListText>
                    </ListRow>
                    <ListRow>
                      <ListLabel text="Fiat Pool Factor" />
                      <ListText>{fiatPool}</ListText>
                    </ListRow>
                    <ListRow>
                      <ListLabel text="Reward Distribution" />
                      <ListText>{distribution}</ListText>
                    </ListRow>
                    <ListRow>
                      <ListLabel text="Grading Process" />
                      <ListText>{process}</ListText>
                    </ListRow>
                    <ListRow>
                      <ListLabel text="Active" />
                      <ListText>{active}</ListText>
                    </ListRow>
                    {/* <ListRow>
                      <ListLabel text="Start Block:" />
                      <ListText>{start}</ListText>
                    </ListRow>
                    <ListRow>
                      <ListLabel text="End Block" />
                      <ListText>{end}</ListText>
                    </ListRow> */}
                  </List>
                </>
              </SidePanelTop>
            </SidePaneHeader>
            <SidePaneBody>
              <EmptyBody>
                <TextBig>Purpose</TextBig>
                <MarkdownText>
                  <Markdown
                    plugins={[gfm]}
                    // className="overflow-auto text-left"
                    children={kpi.purpose}
                  />
                </MarkdownText>
                {scope && (
                  <>
                    <TextBig>Scope of Work</TextBig>
                    <MarkdownText>
                      {scope.length ? (
                        scope.map((text, i) => (
                          <Markdown key={i} plugins={[gfm]} children={text} />
                        ))
                      ) : (
                        <Markdown plugins={[gfm]} children={scope} />
                      )}
                    </MarkdownText>
                  </>
                )}
                {rewardDistribution && (
                  <MarkdownText>
                    <Markdown
                      plugins={[gfm]}
                      className="overflow-auto text-left"
                      children={rewardDistribution}
                    />
                  </MarkdownText>
                )}
              </EmptyBody>
            </SidePaneBody>
          </>
        )}
      </SidePaneKpi>
    </SidePaneGlass>
  );
});

const SidePaneKpi = styled(SidePane)`
  grid-template-rows: minmax(auto, 320px) 1fr auto;
`;
