import React, { useState } from 'react';
import styled from 'styled-components';

import { BlockIcon, BlockIconStyles } from '@components/icons';

import { PageLayout, PageHeaderWrapper } from '@/app/components/PageLayout';
import { RowGapBlock } from '@components/page/PageContent';
import { PageTitle } from '@components/page/PageTitle';

import {
  BlockDurationStatistics,
  MultiValueStat,
  Statistics,
} from '@components/statistics';
import {
  MultiStatisticItem,
  StatsBlock,
  StatisticItem,
  StatisticLabel,
  StatisticItemProps,
  StatisticItemSpacedContent,
  StatisticHeader,
  StatisticHeaderProps,
  TotalValue,
} from '@components/statistics';
import {
  Select,
  SelectedOption,
  Option,
  OptionsListComponent,
} from '@components/selects';
import { DurationValue } from '@components/typography/DurationValue';
import { TextInlineSmall } from '@components/typography';
import { ColumnGapBlock } from '@components/page/PageContent';
import { AN_HOUR, A_DAY, A_MINUTE, A_WEEK, Fonts } from '@common/constants';
import {
  Checkbox,
  InlineToggleWrap,
  InputComponent,
  InputText,
  InputTextarea,
  Label,
  LabelLink,
  ToggleCheckbox,
} from '@components/forms';

import ValidatorRewards from './ValidatorRewards';
import Loading from '../Loading';


const renderSelected = (option: any) => (
  <SelectedOption>{option.label}</SelectedOption>
);

const JSSelect = ({ options, onChange }: { options: any[], onChange: Function }) => {
  const [selected, setSelected] = useState(options[0]);

  const handleChange = (item: any, cb: any) => {
    setSelected(item);
    onChange && onChange(item);
    cb();
  };

  return (
    <Select
      selected={selected}
      onChange={handleChange}
      // disabled={disabled}
      renderSelected={renderSelected}
      placeholder="Select account or paste account address"
      renderList={(onOptionClick) => (
        <OptionList onChange={onOptionClick} options={options} />
      )}
      // onSearch={(search) => setSearch(search)}
    />
  );
};

export default JSSelect;

interface Props {
  options: any[];
  onChange: (option: any) => void;
}

const OptionList = React.memo(({ options, onChange }: Props) => (
  <OptionsListComponent>
    {options.map((option) => (
      <Option
        key={option.key || option.id}
        onClick={() => onChange && onChange(option)}
      >
        {option.label}
      </Option>
    ))}
  </OptionsListComponent>
));
